OC.L10N.register(
    "core",
    {
    "Please select a file." : "Tafadhali teua faili",
    "File is too big" : "Faili ni kubwa mno",
    "The selected file is not an image." : "Faili lililoteuliwa si taswira",
    "The selected file cannot be read." : "Faili lililochaguliwa halisomeki",
    "The file was uploaded" : "Faili lilipakiwa",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Faili lililopakiwa linazidi kiwango cha juu cha ukubwa wa faili linalielekea katika php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Faili iliyopakiliwa imezidi kiwango cha ukubwa wa faili iliyoelekezwa maalum katika fomu ya HTML",
    "The file was only partially uploaded" : "Faili lilipakiwa kwa sehemu ndogo tu",
    "No file was uploaded" : "Hakuna faili lililopakiwa",
    "Missing a temporary folder" : "Imekosa faili la muda",
    "Could not write file to disk" : "Haikuweza kuandika faili kwenye disk",
    "A PHP extension stopped the file upload" : "Uongezaji wa PHP umesimamisha upakiaji wa faili",
    "Invalid file provided" : "Faili iliyotolewa si halali",
    "No image or file provided" : "Hakuna taswira au faili lililotolewa",
    "Unknown filetype" : "Aina ya faili haijulikani",
    "An error occurred. Please contact your admin." : "Hitilafu imetokea. Tafadhali wasiliana na msimamizi wako",
    "Invalid image" : "Taswira si halisi",
    "State token does not match" : "Tokeni ya Serikali hailingani",
    "Invalid app password" : "Nenosiri la app si halali",
    "Could not complete login" : "Haiwezi kukamilisha uingiaji",
    "State token missing" : "Tokeni ya Serikali inakosekana",
    "Your login token is invalid or has expired" : "Tokeni za uingiaji wako si halali au zimepitwa wakati",
    "Please use original client" : "Tafadhali tumia mteja halisi",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Toleo hili la jumuiya la Nextcloud halitumiki na arifa zinazotumwa na programu huzuiwa.",
    "Login" : "Ingia",
    "Unsupported email length (>255)" : "Urefu wa barua pepe usiotumika (>255)",
    "Password reset is disabled" : "Uwekaji mpya wa nenosiri umezimwa",
    "Could not reset password because the token is expired" : "Haikuweza kuweka upya nenosiri kwa sababu tokeni zimeisha muda wake wa matumizi",
    "Could not reset password because the token is invalid" : "Haikuweza kuweka upya nenosiri kwa sababu tokeni si halali",
    "Password is too long. Maximum allowed length is 469 characters." : "Nenosiri ni refu sana. Kiwango cha juu cha urefu ulioruhusiwa ni wahusika 469",
    "%s password reset" : "%s weka nenosiri upya",
    "Password reset" : "Uwekaji mpya wa nenosiri",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Bofya kitufe kifuatacho ili kuweka upya nenosiri lako. Ikiwa haujaomba kuweka upya nenosiri, basi puuza barua pepe hii.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Bofya kiungo kifuatacho ili kuweka upya nenosiri lako. Ikiwa hujaomba kuweka upya nenosiri, basi puuza barua pepe hii.",
    "Reset your password" : "Pangilia upya nenosiri lako",
    "The given provider is not available" : "Mgavi aliyetolewa hapatikani",
    "Task not found" : "Jukumu halijapatikana",
    "Internal error" : "Hitilafu ya ndani",
    "Not found" : "Haipatikani",
    "Node is locked" : "Nodi imefungwa",
    "Bad request" : "Uombaji mbaya",
    "Requested task type does not exist" : "Uandikaji wa jukumu lililoombwa haupatikani",
    "Necessary language model provider is not available" : "Mgavi muhimu wa aina ya lugha hapatikani",
    "No text to image provider is available" : "Hakuna maandishi yaliyopo kwa mgavi wa taswira",
    "Image not found" : "Taswira haipatikani",
    "No translation provider available" : "Hakuna mgavi wa tafsiri aliyepo",
    "Could not detect language" : "Haikuweza kugundua lugha",
    "Unable to translate" : "Haiwezi kutafsiri",
    "[%d / %d]: %s" : "[%d/%d]: %s",
    "Repair step:" : "Rekwbisha hatua:",
    "Repair info:" : "Rekebisha taarifa",
    "Repair warning:" : "Rekebisha onyo:",
    "Repair error:" : "Rekebisha hitilafu:",
    "Nextcloud Server" : "Seva ya Nextcloud",
    "Some of your link shares have been removed" : "Baadhi ya ushirikishaji wa kiungo chako umeondolewa",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Kwa sababu ya hitilafu ya usalama ilitubidi kuondoa baadhi ya viungio vyako vilivyoshirikishwa. Tafadhali tazama kiungo kwa habari zaidi.",
    "The account limit of this instance is reached." : "Kikomo cha akaunti cha tukio hili kimefikiwa.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Weka ufunguo wako wa usajili katika programu ya usaidizi ili kuongeza kikomo cha akaunti. Hii pia hukupa manufaa yote ya ziada ambayo Nextcloud Enterprise inatoa na inapendekezwa sana kwa uendeshaji ndani ya makampuni.",
    "Learn more ↗" : "Jifunze zaidi",
    "Preparing update" : "Andaa usasishaji",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Tafadhali tumia kisasisho cha mstari wa amri kwa sababu kusasisha kupitia kivinjari kumezimwa katika config.php yako.",
    "Turned on maintenance mode" : "Hali ya matengenezo imewashwa",
    "Turned off maintenance mode" : "Hali ya matengenezo imezimwa",
    "Maintenance mode is kept active" : "Hali ya matengenezo iko hai",
    "Updating database schema" : "Skema ua kanzidata inasasishwa",
    "Updated database" : "Kanzidata iliyosasishwa",
    "Update app \"%s\" from App Store" : "Sasisha program \"%s\" kutoka katika stoo ya program",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Kuangalia kama schema ya kanzidata ya %s inaweza kusasishwa (hii inaweza kuchukua muda mrefu kulingana na saizi ya kanzidata) ",
    "Updated \"%1$s\" to %2$s" : "Imesasishwa \"%1$s\" kwenda %2$s",
    "Set log level to debug" : "Pangilia kiwango kirefu kwenda utatuzi",
    "Reset log level" : "Weka upya kiwango kirefu",
    "Starting code integrity check" : "Inaanza ukaguzi wa uadilifu wa msimbo",
    "Finished code integrity check" : "Imemaliza ukaguzi wa uadilifu wa msimbo",
    "%s (incompatible)" : "%s (isiyooana)",
    "The following apps have been disabled: %s" : "Program zifuatazo hazijawezeshwa:%s",
    "Already up to date" : "Imesasishwa tayari",
    "Windows Command Script" : "Hati ya amri ya Windows",
    "Electronic book document" : "Nyaraka za kitabu cha kielektroniki",
    "TrueType Font Collection" : "Ukusanyaji wa TrueType Front",
    "Web Open Font Format" : "Muundo wa mbele wa Wavuti",
    "GPX geographic data" : "Data za kijiografia za GPX",
    "Gzip archive" : "Kumbukumbu za Gzip",
    "Adobe Illustrator document" : "Waraka wa uelekezaji wa Adobe",
    "Java source code" : "Chanzo cha msimbo wa Java",
    "JavaScript source code" : "Chanzo cha msimbo wa JavaScript",
    "JSON document" : "Waraka wa JSON",
    "Microsoft Access database" : "Ufikiaji wa kanzidata ya Microsoft",
    "Microsoft OneNote document" : "Waraka wa Microsoft OneNote",
    "Microsoft Word document" : "Waraka wa Microsoft Word",
    "Unknown" : "Haijulikani",
    "PDF document" : "Waraka wa PDF",
    "PostScript document" : "Waraka wa PostScript",
    "RSS summary" : "Ufupishaji wa RSS",
    "Android package" : "Kifurushi cha Android",
    "KML geographic data" : "Data za kijiografia za KML",
    "KML geographic compressed data" : "Data za kijiografia za KML zilizofinywa",
    "Lotus Word Pro document" : "Hati ya Lotus Word Pro",
    "Excel spreadsheet" : "Lahajedwali ya Excel",
    "Excel add-in" : "Nyongeza ya Excel",
    "Excel 2007 binary spreadsheet" : "Excel 2007 yenye jozi za lahajedwali",
    "Excel spreadsheet template" : "Kiolezo cha lahajedwali cha Excel",
    "Outlook Message" : "Mtazamo wa ujumbe",
    "PowerPoint presentation" : "Uwasilishaji wa Powerpoint",
    "PowerPoint add-in" : "Program jalizi ya PowerPoint",
    "PowerPoint presentation template" : "Uwasilishaji wa kiolezo cha Powerpoint",
    "Word document" : "Waraka wa maneno",
    "ODF formula" : "Fomula ya ODF",
    "ODG drawing" : "Mchoro wa ODG",
    "ODG drawing (Flat XML)" : "Mchoro wa ODG (Flat XML)",
    "ODG template" : "Kiolezo cha ODG",
    "ODP presentation" : "Uwasilishaji wa ODP",
    "ODP presentation (Flat XML)" : "Uwasilishaji wa ODP (Flat XML)",
    "ODP template" : "Kiolezo cha ODP",
    "ODS spreadsheet" : "Lahajedwali ya ODS",
    "ODS spreadsheet (Flat XML)" : "Lahajedwali ya ODS (Flat XML)",
    "ODS template" : "Kiolezo chz ODS",
    "ODT document" : "Waraka wa ODT",
    "ODT document (Flat XML)" : "Waraka wa ODT (Flat XML)",
    "ODT template" : "Kiolezo cha ODT",
    "PowerPoint 2007 presentation" : "Uwasilishaji wa Powerpoint ya 2007",
    "PowerPoint 2007 show" : "Onesho la PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Kiolezo cha uwasilishaji wa PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Lahajedwali ya Excel 2007",
    "Excel 2007 spreadsheet template" : "Kiolezo cha lahajedwali ya Excel 2007",
    "Word 2007 document" : "Hati ya Word 2007",
    "Word 2007 document template" : "Kiolezo cha hati ya Word 2007",
    "Microsoft Visio document" : "Hati ya Microsoft Visio",
    "WordPerfect document" : "Hati ya WordPerfect",
    "7-zip archive" : "Kumbukumbu ya 7-zip",
    "Blender scene" : "Tukio la blender",
    "Bzip2 archive" : "Kumbukumbu ya Bzip2",
    "Debian package" : "Kifurushi cha Debian",
    "FictionBook document" : "Hati ya kitabu cha Fiction",
    "Unknown font" : "Fonti isiyojulikana",
    "Krita document" : "Hati ya Krita",
    "Mobipocket e-book" : "Kitabu cha kielektroniki cha Mobpocket",
    "Windows Installer package" : "Kifurushi cha kisakinishi cha Windows",
    "Perl script" : "Hati ya Perl",
    "PHP script" : "Hati ya PHP",
    "Tar archive" : "Kumbukumbu ya Tar",
    "XML document" : "Waraka wa XML",
    "YAML document" : "Waraka wa YAML",
    "Zip archive" : "Kumbukumbu za Zip",
    "Zstandard archive" : "Kumbukumbu za Zstandard",
    "AAC audio" : "Sauti ya AAC",
    "FLAC audio" : "Sauti ya FLAC",
    "MPEG-4 audio" : "Sauti ya MPEG-4",
    "MP3 audio" : "Sauti ya MP3",
    "Ogg audio" : "Sauti ya Ogg",
    "RIFF/WAVe standard Audio" : "Sauti ya RIFF/WAVe standard",
    "WebM audio" : "Sauti ya WebM",
    "MP3 ShoutCast playlist" : "Orodha ya kucheza ya MP3 ShoutCast",
    "Windows BMP image" : "Taswira ya Windows BMP",
    "Better Portable Graphics image" : "Picha bora ya Michoro inayobebeka",
    "EMF image" : "Taswira ya EMF",
    "GIF image" : "Taswira ya GIF",
    "HEIC image" : "Taswira ya HEIC",
    "HEIF image" : "Taswira ya HEIF",
    "JPEG-2000 JP2 image" : "Taswira ya JPEG-2000 JP2",
    "JPEG image" : "Taswira ya JEPG",
    "PNG image" : "Taswira ya PNG",
    "SVG image" : "Taswira ya SVG",
    "Truevision Targa image" : "Taswira ya Truevision Targa",
    "TIFF image" : "Taswira ya TIFF",
    "WebP image" : "Taswira ya WavutiP",
    "Digital raw image" : "Taswira mbichi ya kidijitali",
    "Windows Icon" : "Aikoni ya window",
    "Email message" : "Jumbe za barua pepe",
    "VCS/ICS calendar" : "Kalenda ya VCS/ICS",
    "CSS stylesheet" : "Laha ya mtindo ya CSS",
    "CSV document" : "Waraka wa CSV",
    "HTML document" : "Waraka wa HTML",
    "Markdown document" : "Hati ya alama",
    "Org-mode file" : "Faili ya modi ya Org",
    "Plain text document" : "Hati ya maandishi wazi",
    "Rich Text document" : "Hati ya maandishi tajiri",
    "Electronic business card" : "Kadi ya biashara ya kielektroniki",
    "C++ source code" : "Msimbo wa chanzo C++",
    "LDIF address book" : "Kitabu cha anwani cha LDIF",
    "NFO document" : "Waraka wa NFO",
    "PHP source" : "Chanzo cha PHP",
    "Python script" : "Hati ya Python",
    "ReStructuredText document" : "Hati ya Nakala Iliyoundwa upya",
    "3GPP multimedia file" : "Faili ya media titika ya 3GPP",
    "MPEG video" : "Picha mjongeo ya MPEG",
    "DV video" : "Picha mjongeo ya DV",
    "MPEG-2 transport stream" : "Mkondo wa usafiri wa MPEG-2",
    "MPEG-4 video" : "Picha mjongeo ya MPEG-4",
    "Ogg video" : "Picha mjongeo ya Ogg",
    "QuickTime video" : "Picha mjongeo ya QuickTime",
    "WebM video" : "Picha mjongeo ya WebM",
    "Flash video" : "Picha mjongeo ya Flash",
    "Matroska video" : "Picha mjongeo ya Matroska",
    "Windows Media video" : "Picha mjongeo ya Windows Media",
    "AVI video" : "Picha mjongeo ya AVI",
    "unknown text" : "andiko lisilojulikana",
    "Hello world!" : "Halo dunia!",
    "sunny" : "a jua",
    "Hello {name}, the weather is {weather}" : "Halo{name}, hali ya hewa ni {weather}",
    "Hello {name}" : "Halo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Haya ni matokeo ya utafutaji wako<script>toa taarifa(1)</script></strong>",
    "new" : "mpya",
    "_download %n file_::_download %n files_" : ["download %n file","pakua faili %n "],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Usasishaji unaendelea, kuacha ukurasa huu kunaweza kukatiza mchakato katika baadhi ya mazingira",
    "Update to {version}" : "Sasisha kwenda {version}",
    "An error occurred." : "Hitilafu imetokea",
    "Please reload the page." : "Tafadhali pakia ukurasa upya ",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Usasishaji haujafaulu. Kwa habari zaidi<a href=\"{url}\"> angalia chapisho letu la jukwaa </a> linaloangazia suala hili.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uasasishaji umefanikiwa. Tafadhali toa taarifa ya jambo hili kwenye <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Jamii ya Nextcloud</a>.",
    "Continue to {productName}" : "Endelea katika {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second."," Usasishaji umekamilika. Elekeza upya katika {productName} ndani ya %n sekunde."],
    "Applications menu" : "Mwongozo wa maombi",
    "Apps" : "Maombi",
    "More apps" : "Apps zaidi",
    "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} taarifa"],
    "No" : "Hapana",
    "Yes" : "Ndiyo",
    "The remote URL must include the user." : "Rimoti ya URL lazima ijumuishe mtumiaji",
    "Invalid remote URL." : "Rimoti ya URL si halali",
    "Failed to add the public link to your Nextcloud" : "Imeshindwa kuongeza kiungio cha jamii kwenye Nextcloud yako",
    "Federated user" : "Mtumiaji aliyeshirikishwa",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "Tengeneza ushirikishaji",
    "Direct link copied" : "Kiungo cha moja kwa moja kimenakiliwa",
    "Please copy the link manually:" : "Tafadhali nakili kiungio kikawaida",
    "Custom date range" : "Safu ya tarehe maalum",
    "Pick start date" : "Chagua tarehe ya kuanza",
    "Pick end date" : "Chagua tarehe ya mwisho",
    "Search in date range" : "Tafuta katika safu ya tarehe",
    "Search in current app" : "Tafuta katika app ya hivi karibuni",
    "Clear search" : "Futa utafutaji",
    "Search everywhere" : "Tafuta kila mahali",
    "Searching …" : "Inatafuta",
    "Start typing to search" : "Anza kuandika ili kutafuta",
    "No matching results" : "Hakuna matokeo yanayolingana",
    "Today" : "Leo",
    "Last 7 days" : "Siku 7 zilizopita",
    "Last 30 days" : "Siku 30 zilizopita",
    "This year" : "Mwaka huu",
    "Last year" : "Mwaka uliopita",
    "Between {startDate} and {endDate}" : "Kati ya {startDate} na {endDate}",
    "Unified search" : "Utafutaji wa umoja",
    "Search apps, files, tags, messages" : "Tafuta app, faili, lebo, jumbe",
    "Places" : "Maeneo",
    "Date" : "Tarehe",
    "Search people" : "Tafuta watu",
    "People" : "Watu",
    "Filter in current view" : "Chuja katika mwonekano wa sasa",
    "Search connected services" : "Tafuta huduma zilizounganishwa",
    "Results" : "Matokeo",
    "Load more results" : "Pakia matokeo zaidi",
    "Search in" : "Tafuta katika",
    "Log in" : "Ingia",
    "Logging in …" : "Inaingia",
    "Log in to {productName}" : "Ingia kwa {productName}",
    "Wrong login or password." : "Makosa ya uingiaji au nenosiri",
    "This account is disabled" : "Akaunti hii haijawezeshwa ",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Tumegundua majaribio mengi batili ya kuingia kutoka kwa IP yako. Kwa hivyo kuingia kwako kunakofuata kunasisitizwa hadi sekunde 30.",
    "Account name or email" : "Jina la akaunti au barua pepe",
    "Account name" : "Jina la akaunti",
    "Server side authentication failed!" : "Uthibitishaji wa upande wa seva umeshindwa",
    "Please contact your administrator." : "Tafadhali wasiliana na msimamizi wako",
    "Session error" : "Hitilafu ya kipindi",
    "It appears your session token has expired, please refresh the page and try again." : "Inaonekana tokeni za kipindi chako zimepitwa na wakati, tafadhali pumzisha ukurasa na ujaribu tena.",
    "An internal error occurred." : "Hitilafu ya ndani imetokea",
    "Please try again or contact your administrator." : "Tafadhali jaribu tena au wasiliana na msimamizi wako",
    "Password" : "Nenosiri",
    "Log in with a device" : "Ingia na kifaa",
    "Login or email" : "Ingia au barua pepe",
    "Your account is not setup for passwordless login." : "Akaunti yako haijapangiliwa uingiaji bila nenosiri",
    "Your connection is not secure" : "Muunganisho wako si salama",
    "Passwordless authentication is only available over a secure connection." : "Uthibitisho wa bila nenosiri upo tu penye usalalma wa hali ya juu",
    "Browser not supported" : "Kivinjari hakitumiki",
    "Passwordless authentication is not supported in your browser." : "Uthibitisho wa bila nenosiri hautumiki katika kivinjari chako",
    "Reset password" : "Pangilia upya nenosiri",
    "Back to login" : "Rudi kwenye uingiaji",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Kama akaunti hii ipo, ujumbe wa kuweka upya nenosiri umetumwa kwa anwani yake ya barua pepe. Usipoipokea, thibitisha anwani yako ya barua pepe na/au Ingia, angalia folda zako za barua taka au taka au uombe usaidizi wa utawala wa eneo lako.",
    "Couldn't send reset email. Please contact your administrator." : "Haiwezi kutuma barua pepe iliyowekwa upya. Tafadhali wasiliana na msimamizi wako",
    "Password cannot be changed. Please contact your administrator." : "Nenosiri haliwezi kubadilishwa. Tafadhali wasiliana na msimamizi wako",
    "New password" : "Nenosiri jipya",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Faili zako zimesimbwa kwa njia fiche. Hakutakuwa na njia ya kurejesha data yako baada ya kuweka upya nenosiri lako. Ikiwa huna uhakika wa kufanya, tafadhali wasiliana na msimamizi wako kabla ya kuendelea. Je, kweli unataka kuendelea?",
    "I know what I'm doing" : "Ninajua nikifanyacho",
    "Resetting password" : "Inaweka upya nenosiri",
    "Schedule work & meetings, synced with all your devices." : "Ratibu kazi na mikutano, iliyosawazishwa na vifaa vyako vyote.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Waweke wenzako na marafiki katika sehemu moja bila kuvujisha habari zao za faragha.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Programu rahisi ya barua pepe iliyounganishwa vizuri na Faili, Anwani na Kalenda.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Kupiga gumzo, simu za video, kushiriki skrini, mikutano ya mtandaoni na mikutano ya wavuti - katika kivinjari chako na programu za simu.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Hati shirikishi, lahajedwali na mawasilisho, yaliyoundwa kwenye Collabora mtandaoni.",
    "Distraction free note taking app." : "Programu ya kuchukua nukuu bila usumbufu.",
    "Recommended apps" : "Program iliyopendekezwa",
    "Loading apps …" : "Inapakia program",
    "Could not fetch list of apps from the App Store." : "Haiwezi kuleta orodha ya maombi kutoka katika stoo ya maombi",
    "App download or installation failed" : "Upakuaji au usanikishaji wa program umeshindikana",
    "Cannot install this app because it is not compatible" : "Haiwezi kusakinisha program hii kwa sababu si sambamba",
    "Cannot install this app" : "Haiwezi kusakinisha program hii",
    "Skip" : "Ruka",
    "Installing apps …" : "Inasakinisha program",
    "Install recommended apps" : "Sakinisha program zilizopendekezwa",
    "Avatar of {displayName}" : "Avatar ya {displayName}",
    "Settings menu" : "Pangilia mwongozo",
    "Loading your contacts …" : "Inapakia mawasiliano yako",
    "Looking for {term} …" : "Inatafuta {term}",
    "Search contacts" : "Tafuta mawasiliano",
    "Reset search" : "Pangilia utafutaji",
    "Search contacts …" : "Tafuta mawasiliano...",
    "Could not load your contacts" : "Haikuweza kupakia mawasiliano yako",
    "No contacts found" : "Hakuna mawasiliano yaliyopatikana",
    "Show all contacts" : "Onesha mawasiliano yote",
    "Install the Contacts app" : "Sakinisha program ya mawasiliano",
    "Search" : "Tafuta",
    "No results for {query}" : "Hakuna matokeo kwa {query}",
    "Press Enter to start searching" : "Bonyeza ingia kuanza kutafuta",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Tafadhali weka vibambo {minSearchLength} au zaidi ili kutafuta"],
    "An error occurred while searching for {type}" : "Hitilafu imetokea wakati ikitafuta {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Utafutaji huanza mara moja unapoanza kuandika na matokeo yanaweza kufikiwa na funguo za mishale",
    "Search for {name} only" : "Tafuta tu {name}",
    "Loading more results …" : "Inapakia matokeo zaidi",
    "Forgot password?" : "Umesahau nenosiri?",
    "Back to login form" : "Rudi kwenye fomu ya uingiaji",
    "Back" : "Rudi",
    "Login form is disabled." : "Fomu ya uingiaji haikuwezeshwa",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Fomu ya kuingia ya Nextcloud imezimwa. Tumia chaguo jingine la kuingia ikiwa linapatikana au wasiliana na utawala wako.",
    "More actions" : "Vitendo zaidi",
    "User menu" : "Mwongozo wa mtumiaji",
    "Your guest name: {user}" : "Jina la mgeni wako: {user}",
    "You are currently not identified." : "Kwa sasa hutambuliki",
    "Set public name" : "Pangilia jina la umma",
    "Change public name" : "Badili jina la umma",
    "Password is too weak" : "Nenosiri ni dhaifu sana",
    "Password is weak" : "Nenosiri ni dhaifu",
    "Password is average" : "Nenosiri ni wastani",
    "Password is strong" : "Nenosiri ni imara",
    "Password is very strong" : "Nenosiri ni imara sana",
    "Password is extremely strong" : "Nenosiri ni imara zaidi sana",
    "Unknown password strength" : "Nguvu ya nenosiri haijulikani",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Saraka yako ya data na faili pengine zinaweza kufikiwa kutoka kwa mtandao kwa sababu faili ya <code>.htaccess</code> haifanyi kazi.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Kwa maelezo ya jinsi ya kusanidi seva yako ipasavyo, tafadhali {linkStart} tazama hati {linkEnd}",
    "Autoconfig file detected" : "Faili ya usanidi otomatiki imegunduliwa",
    "The setup form below is pre-filled with the values from the config file." : "Fomu iliyopo hapa chini imejaa thamani kutoka kwa faili ya usanidi.",
    "Security warning" : "Onyo la usalama",
    "Create administration account" : "Tengeneza akaunti ya msimamizi",
    "Administration account name" : "Jina la akaunti ya msimamizi",
    "Administration account password" : "Nenosiri la akaunti ya msimamizi",
    "Storage & database" : "Uhifadhi na kanzidata",
    "Data folder" : "Kisanduku cha data",
    "Database configuration" : "Usanidi wa kanzi data",
    "Only {firstAndOnlyDatabase} is available." : "Yupo tu {firstAndOnlyDatabase}",
    "Install and activate additional PHP modules to choose other database types." : "Sakinisha na uwashe moduli za ziada za PHP ili kuchagua aina zingine za hifadhidata",
    "For more details check out the documentation." : "Kwa maelezo zaidi angalia nyaraka ",
    "Performance warning" : "Onyo la utendaji kazi",
    "You chose SQLite as database." : "Umechagua SQLite kama kanzidata",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite inapaswa kutumika tu kwa hali ndogo na za ukuzaji. Kwa ajili ya uzalishaji tunapendekeza mazingira tofauti ya hifadhidata.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ikiwa unatumia wateja kusawazisha faili, utumiaji wa SQLite umekatishwa tamaa sana.",
    "Database user" : "Mtumiaji wa kanzidata",
    "Database password" : "Nenosiri la kanzidata",
    "Database name" : "Jina la kanzidata",
    "Database tablespace" : "Nafasi ya meza ya kanzidata",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Tafadhali bainisha nambari ya mlango pamoja na jina la mwenyeji (k.m., mwenyeji wa eneo:5432).",
    "Database host" : "Mwenyeji wa kanzidata",
    "localhost" : "mwenyeji wa eneo",
    "Installing …" : "Inasakinisha",
    "Install" : "Sakinisha",
    "Need help?" : "Unahitaji masaada?",
    "See the documentation" : "Angalia mkusanyiko wa nyaraka",
    "{name} version {version} and above" : "{name} toleo {version}na juu",
    "This browser is not supported" : "Kivinjari hiki hakitumiki",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Kivinjari chako hakitumiki. Tafadhali boresha hadi toleo jipya au kivinjari kinachotumika",
    "Continue with this unsupported browser" : "Endelea na kivinjari kisichotumika",
    "Supported versions" : "Toleo linalotumika",
    "Search {types} …" : "Tafuta {types}...",
    "Choose {file}" : "Chagua {file}",
    "Choose" : "Chagua",
    "Copy to {target}" : "Nakili kwenda {target}",
    "Copy" : "Nakili",
    "Move to {target}" : "Hamishia {target}",
    "Move" : "Hamisha",
    "OK" : "Sawa",
    "read-only" : "soma tu",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} file conflict","{count} migogoro ya faili"],
    "One file conflict" : "Mgogoro mmoja wa faili",
    "New Files" : "Faili mpya",
    "Already existing files" : "Faili zilizopo tayari",
    "Which files do you want to keep?" : "Faili ipi unataka kuliweka",
    "If you select both versions, the copied file will have a number added to its name." : "Kama utachagua matoleo yote, faili zilizonakiliwa zitakuwa na namba zilizoongezeka kwenye jina lake",
    "Cancel" : "Cancel",
    "Continue" : "Endelea",
    "(all selected)" : "(yote yamechaguliwa)",
    "({count} selected)" : "({count} imechaguliwa)",
    "Error loading file exists template" : "Hitilafu kupakia faili kiolezo kilichopo",
    "Saving …" : "Inahifadhi...",
    "seconds ago" : "sukunde zilizopita",
    "Connection to server lost" : "Muunganiko kwenye seva umepotea",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Tatizo kupakia ukurasa, pakia upya %n sekunde"],
    "Add to a project" : "Ongeza kwenye mradi",
    "Show details" : "Onesha maelezo",
    "Hide details" : "Ficha maelezo",
    "Rename project" : "Ita mradi jina jipya",
    "Failed to rename the project" : "Imeshindwa kuupa mradi jina jipya",
    "Failed to create a project" : "Imeshindwa kutengeneza mradi",
    "Failed to add the item to the project" : "Imeshindwa kuongeza kipengele katika mradi",
    "Connect items to a project to make them easier to find" : "Unganisha vipengele kwenye mradi kuvifanya vipatikane kwa urahisi",
    "Type to search for existing projects" : "Andika kutafuta kwa miradi iliyopo",
    "New in" : "Mpya katika",
    "View changelog" : "Tazama logi ya mabadiliko",
    "No action available" : "Hakuna kitendo kilichopo",
    "Error fetching contact actions" : "Hitilafu kuleta matendo ya mawasiliano",
    "Close \"{dialogTitle}\" dialog" : "Funga \"{dialogTitle}\" mazungumzo",
    "Email length is at max (255)" : "Urefu wa barua pepe uko katika kuwango cha (255)",
    "Clipboard not available, please copy manually" : "Ubao wa kunakili haupatikani, tafadhali nakili wewe mwenyewe",
    "Personal" : "Binafsi",
    "Accounts" : "Akaunti",
    "Admin" : "Msimamizi",
    "Help" : "Msaada",
    "Access forbidden" : "Ufukiaji umezuiliwa",
    "You are not allowed to access this page." : "Huruhusiwa kufikia ukurasa huu",
    "Back to %s" : "Rudi kwenye %s",
    "Page not found" : "Ukurasa haupatikani",
    "The page could not be found on the server or you may not be allowed to view it." : "Ukurasa haukuweza kupatikana kwenye seva au huenda usiruhusiwe kuutazama.",
    "Too many requests" : "Maombi mengi",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Kulikuwa na maombi mengi kutoka kwa mtandao wako. Jaribu tena baadaye au wasiliana na msimamizi wako ikiwa hili ni kosa.",
    "Error" : "Hitilafu",
    "Internal Server Error" : "Hitilafu ya ndani ya seva",
    "The server was unable to complete your request." : "Seva haikuweza kukamilisha ombi lako.",
    "If this happens again, please send the technical details below to the server administrator." : "Hili likitokea tena, tafadhali tuma maelezo ya kiufundi hapa chini kwa msimamizi wa seva.",
    "More details can be found in the server log." : "Maelezo zaidi yanaweza kupatikana kwenye logi ya seva.",
    "For more details see the documentation ↗." : "Kwa maelezo zaidi angalia wasilisho la nyaraka",
    "Technical details" : "Maelezo ya kiufundi",
    "Remote Address: %s" : "Anwani ya mbali: %s",
    "Request ID: %s" : "Omba utambulisho: %s",
    "Type: %s" : "Aina: %s",
    "Code: %s" : "Kanuni: %s",
    "Message: %s" : "Ujumbe: %s",
    "File: %s" : "Faili:%s",
    "Line: %s" : "Mstari: %s",
    "Trace" : "Fuatilia",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Inaonekana unajaribu kusakinisha tena Nextcloud yako. Walakini faili CAN_INSTALL haipo kwenye saraka yako ya usanidi. Tafadhali unda faili CAN_INSTALL katika folda yako ya usanidi ili kuendelea.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Haikuweza kuondoa CAN_INSTALL kutoka kwa folda ya usanidi. Tafadhali ondoa faili hii wewe mwenyewe.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Programu hii inahitaji JavaScript kwa uendeshaji sahihi. Tafadhali {linkstart} wezesha JavaScript {linkend} na upakie upya ukurasa.",
    "Skip to main content" : "Ruka hadi kwenye lengo kuu",
    "Skip to navigation of app" : "Ruka hadi kwenye usogezaji wa program",
    "Go to %s" : "Nenda kwenye %s",
    "Get your own free account" : "Pata akaunti yako ya bure",
    "Connect to your account" : "Unganisha kwenye akaunti yako",
    "Please log in before granting %1$s access to your %2$s account." : "Tafadhali ingia kabla ya kutoa %1$s ufikiaji kwenye akaunti yako %2$s",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Iwapo hujaribu kusanidi kifaa au programu mpya, mtu anajaribu kukuhadaa ili umpe idhini ya kufikia data yako. Katika kesi hii usiendelee na badala yake wasiliana na msimamizi wa mfumo wako.\n ",
    "App password" : "Nenosiri la program",
    "Grant access" : "Toa ufikiaji",
    "Alternative log in using app password" : "Uingiaji mbadala kutumia nenosiri la program",
    "Account access" : "Ufikiaji wa akaunti",
    "Currently logged in as %1$s (%2$s)." : "Sasa umeingia kama %1$s (%2$s)",
    "You are about to grant %1$s access to your %2$s account." : "Unakaribia kutoa %1$s uingiaji %2$skwenye akaunti yako",
    "Account connected" : "Akaunti imeunganishwa",
    "Your client should now be connected!" : "Mteja wako anapaswa kuunganishwa sasa",
    "You can close this window." : "Unaweza kufunga window hii",
    "Previous" : "Iliyopita",
    "This share is password-protected" : "Ushirikishaji huu unalindwa na nenosiri",
    "The password is wrong or expired. Please try again or request a new one." : "Nenosiri si sahihi au limeisha muda wake. Tafadhali jaribu tena au uombe mpya.",
    "Please type in your email address to request a temporary password" : "Tafadhali andika ndani ya barua pepe yako kuomba nenosiri la muda",
    "Email address" : "Anwani ya barua pepe",
    "Password sent!" : "Nenosiri limetumwa",
    "You are not authorized to request a password for this share" : "Hujathibitishwa kuomba nenosiri kwa uwasilishaji huu",
    "Two-factor authentication" : "Uthibitishaji wa mambo mawili",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Usalama ulioimarishwa umewezeshwa kwa akaunti yako. Chagua kipengele cha pili cha uthibitishaji:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Haikuweza kupakia angalau mojawapo ya mbinu zako za uthibitishaji wa vipengele viwili vilivyowezeshwa. Tafadhali wasiliana na msimamizi wako.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Uthibitishaji wa vipengele viwili unatekelezwa lakini haujasanidiwa kwenye akaunti yako. Wasiliana na msimamizi wako kwa usaidizi.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Uthibitishaji wa vipengele viwili unatekelezwa lakini haujasanidiwa kwenye akaunti yako. Tafadhali endelea kusanidi uthibitishaji wa vipengele viwili.",
    "Set up two-factor authentication" : "Sanidi uthibitishaji wa vipengele viwili",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Uthibitishaji wa vipengele viwili unatekelezwa lakini haujasanidiwa kwenye akaunti yako. Tumia mojawapo ya misimbo yako mbadala kuingia au kuwasiliana na msimamizi wako kwa usaidizi.",
    "Use backup code" : "Tumia nambari ya kuthibitisha",
    "Cancel login" : "Sitisha uingiaji",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Usalama ulioimarishwa unatekelezwa kwa akaunti yako. Chagua ni mtoa huduma gani wa kuweka:",
    "Error while validating your second factor" : "Hitilafu wakati wa kuthibitisha kipengele chako cha pili",
    "Access through untrusted domain" : "Fikia kupitia kikoa kisichoaminika",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Tafadhali wasiliana na msimamizi wako. Ikiwa wewe ni msimamizi, hariri mipangilio ya \"vikoa_vinavyoaminika\" katika config/config.php kama mfano katika config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Maelezo zaidi jinsi ya kusanidi haya yanaweza kupatikana katika %1$s hati %2$s ",
    "App update required" : "Usasishaji wa program unahitajika",
    "%1$s will be updated to version %2$s" : "%1$s itasasishwa kwenda toleo %2$s",
    "The following apps will be updated:" : "Programu zifuatazo zitasasishwa:",
    "These incompatible apps will be disabled:" : "Programu hizi zisizooana zitazimwa",
    "The theme %s has been disabled." : "Lengo %s halijawezeshwa",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Tafadhali hakikisha kuwa hifadhidata, folda ya usanidi na folda ya data zimechelezwa kabla ya kuendelea.",
    "Start update" : "Anza usasishaji",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Ili kuzuia kuisha kwa usakinishaji mkubwa, badala yake unaweza kutekeleza amri ifuatayo kutoka kwa saraka yako ya usakinishaji:\n ",
    "Detailed logs" : "Kumbukumbu za kina",
    "Update needed" : "Sasisha inayotakiwa",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Tafadhali tumia kisasisho cha mstari wa amri kwa sababu una tukio kubwa na lenye zaidi ya akaunti 50.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Kwa msaada, angalia <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\"> onesho la nyaraka</a>",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ninajua kuwa ikiwa nitaendelea kusasisha kupitia kiolesura cha wavuti kuna hatari, kwamba ombi linakwenda kwa muda na linaweza kusababisha upotezaji wa data, lakini nina nakala rudufu na ninajua jinsi ya kurejesha mfano wangu ikiwa itashindwa.",
    "Upgrade via web on my own risk" : "Upgrade via web on my own risk",
    "Maintenance mode" : "Modi ya matengenezo",
    "This %s instance is currently in maintenance mode, which may take a while." : "%s kwa sasa ni katika hali ya matengenezo, ambayo inaweza kuchukua muda. ",
    "This page will refresh itself when the instance is available again." : "Ukurasa huu utajipumzisha upya wakati mfano unapatikana tena.\n ",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Wasiliana na msimamizi wa mfumo wako ikiwa ujumbe huu utaendelea au ulionekana bila kutarajiwa.",
    "No temporary profile picture available, try again" : "Hakuna picha ya muda ya wasifu inayopatikana, jaribu tena",
    "No crop data provided" : "Hakuna data iliyokatwa iliyotolewa",
    "No valid crop data provided" : "Hakuna data halali iliyokatwa iliyotolewa",
    "Crop is not square" : "Ukataji si mraba",
    "Error occurred while checking server setup" : "Hitilafu imetokea wakati ikiangalia mpangilio wa seva",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Kwa maelezo zaidi ona {linkstart}uwasilishaji nyaraka {linkend}",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Kupiga gumzo, simu za picha mjongeo, kushiriki skrini, mikutano ya mtandaoni na mikutano ya wavuti - katika kivinjari chako na programu za simu.",
    "You have not added any info yet" : "Hujaongeza taarifa yoyote bado",
    "{user} has not added any info yet" : "{user} hajaongeza taarifa yoyote bado",
    "Error opening the user status modal, try hard refreshing the page" : "Hitilafu imetokea wakati wa kufungua modi ya hali ya mtumiaji, jaribu kuonyesha upya ukurasa kwa bidii",
    "Edit Profile" : "Hariri wasifu",
    "The headline and about sections will show up here" : "Kichwa cha habari na sehemu kuhusu zitaonekana hapa",
    "Very weak password" : "Nenosiri dhaifu sana",
    "Weak password" : "Nenosiri dhaifu",
    "So-so password" : "Nenosiri la so-so",
    "Good password" : "Nenosiri zuri",
    "Strong password" : "Nenosiri imara",
    "Non-existing tag #{tag}" : "Lebo isiyokuwepo #{tag}",
    "Restricted" : "Imezuiliwa",
    "Invisible" : "Haionekani",
    "Delete" : "Futa",
    "Rename" : "Ipe jina jipya",
    "Collaborative tags" : "Lebo zinazoshirikiana",
    "No tags found" : "Hakuna lebo zilizopatikana",
    "Profile not found" : "Wasifu haupatikani",
    "The profile does not exist." : "Wasifu haupo",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Saraka yako ya data na faili pengine zinaweza kufikiwa kutoka kwa mtandao kwa sababu faili ya .htaccess haifanyi kazi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Kwa taarifa jinsi ya kusanidi seva yako vizuri, tafadhali angalia <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">onesho la nyaraka</a>",
    "<strong>Create an admin account</strong>" : "<strong>tengeneza akaunti ya msimsmizi</strong>",
    "New admin account name" : "Jina jipya la akaunti ya msimamizi",
    "New admin password" : "Nenosiri jipya la msimamizi",
    "Show password" : "Onesha nenosiri",
    "Toggle password visibility" : "Geuza mwonekano wa nenosiri",
    "Configure the database" : "Sanidi hifadhidata",
    "Only %s is available." : "Yupo tu %s",
    "Database account" : "Akaunti ya kanzidata",
    "Direct link copied to clipboard" : "Kiungio cha moja kwa moja kimenakiliwa kwenye ubao wa kunakili"
},
"nplurals=2; plural=(n != 1);");
